aboutsummaryrefslogtreecommitdiff
path: root/src/model/guild/role.rs
diff options
context:
space:
mode:
authorZeyla Hellyer <[email protected]>2017-05-22 17:02:00 -0700
committerZeyla Hellyer <[email protected]>2017-05-22 17:02:00 -0700
commit9969be60cf320797c37b317da24d9a08fd5eafa5 (patch)
treef27bf7a57af95bbc11990b1edcea9cca99276964 /src/model/guild/role.rs
parentReasonably derive Debug on items (diff)
downloadserenity-9969be60cf320797c37b317da24d9a08fd5eafa5.tar.xz
serenity-9969be60cf320797c37b317da24d9a08fd5eafa5.zip
Restructure modules
Modules are now separated into a fashion where the library can be used for most use cases, without needing to compile the rest. The core of serenity, with no features enabled, contains only the struct (model) definitions, constants, and prelude. Models do not have most functions compiled in, as that is separated into the `model` feature. The `client` module has been split into 3 modules: `client`, `gateway`, and `http`. `http` contains functions to interact with the REST API. `gateway` contains the Shard to interact with the gateway, requiring `http` for retrieving the gateway URL. `client` requires both of the other features and acts as an abstracted interface over both the gateway and REST APIs, handling the event loop. The `builder` module has been separated from `utils`, and can now be optionally compiled in. It and the `http` feature are required by the `model` feature due to a large number of methods requiring access to them. `utils` now contains a number of utilities, such as the Colour struct, the `MessageBuilder`, and mention parsing functions. Each of the original `ext` modules are still featured, with `cache` not requiring any feature to be enabled, `framework` requiring the `client`, `model`, and `utils`, and `voice` requiring `gateway`. In total the features and their requirements are: - `builder`: none - `cache`: none - `client`: `gateway`, `http` - `framework`: `client`, `model`, `utils` - `gateway`: `http` - `http`: none - `model`: `builder`, `http` - `utils`: none - `voice`: `gateway` The default features are `builder`, `cache`, `client`, `framework`, `gateway`, `model`, `http`, and `utils`. To help with forwards compatibility, modules have been re-exported from their original locations.
Diffstat (limited to 'src/model/guild/role.rs')
-rw-r--r--src/model/guild/role.rs23
1 files changed, 16 insertions, 7 deletions
diff --git a/src/model/guild/role.rs b/src/model/guild/role.rs
index 58f91de..27ae1f9 100644
--- a/src/model/guild/role.rs
+++ b/src/model/guild/role.rs
@@ -3,11 +3,13 @@ use std::fmt::{Display, Formatter, Result as FmtResult};
use ::model::*;
#[cfg(feature="cache")]
-use ::client::{CACHE, rest};
+use ::CACHE;
#[cfg(feature="cache")]
use ::internal::prelude::*;
-#[cfg(feature="cache")]
-use ::utils::builder::EditRole;
+#[cfg(feature="model")]
+use ::http;
+#[cfg(feature="builder")]
+use ::builder::EditRole;
/// Information about a role within a guild. A role represents a set of
/// permissions, and can be attached to one or multiple users. A role has
@@ -21,8 +23,13 @@ pub struct Role {
pub id: RoleId,
/// The colour of the role. This is an ergonomic representation of the inner
/// value.
+ #[cfg(feature="utils")]
#[serde(rename="color")]
pub colour: Colour,
+ /// The colour of the role.
+ #[cfg(not(feature="utils"))]
+ #[serde(rename="color")]
+ pub colour: u32,
/// Indicator of whether the role is pinned above lesser roles.
///
/// In the client, this causes [`Member`]s in the role to be seen above
@@ -55,6 +62,7 @@ pub struct Role {
pub position: i64,
}
+#[cfg(feature="model")]
impl Role {
/// Deletes the role.
///
@@ -64,7 +72,7 @@ impl Role {
#[cfg(feature="cache")]
#[inline]
pub fn delete(&self) -> Result<()> {
- rest::delete_role(self.find_guild()?.0, self.id.0)
+ http::delete_role(self.find_guild()?.0, self.id.0)
}
/// Edits a [`Role`], optionally setting its new fields.
@@ -95,10 +103,10 @@ impl Role {
///
/// # Errors
///
/// Returns a [`ClientError::GuildNotFound`] if a guild is not in the cache
/// that contains the role.
///
- /// [`ClientError::GuildNotFound`]: ../client/enum.ClientError.html#variant.GuildNotFound
+ /// [`ModelError::GuildNotFound`]: enum.ModelError.html#variant.GuildNotFound
#[cfg(feature="cache")]
pub fn find_guild(&self) -> Result<GuildId> {
for guild in CACHE.read().unwrap().guilds.values() {
@@ -109,7 +117,7 @@ impl Role {
}
}
- Err(Error::Client(ClientError::GuildNotFound))
+ Err(Error::Model(ModelError::GuildNotFound))
}
/// Check that the role has the given permission.
@@ -165,6 +173,7 @@ impl PartialOrd for Role {
}
}
+#[cfg(feature="model")]
impl RoleId {
/// Search the cache for the role.
#[cfg(feature="cache")]
@@ -95,10 +103,10 @@ impl Role {
/// # Errors
///
- /// Returns a [`ClientError::GuildNotFound`] if a guild is not in the cache
+ /// Returns a [`ModelError::GuildNotFound`] if a guild is not in the cache
/// that contains the role.
///